[Libreoffice-commits] core.git: qadevOOo/tests stoc/util udkapi/com ure/source

Stephan Bergmann sbergman at redhat.com
Thu Apr 25 08:46:48 PDT 2013


 qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java |   15 +++++++------
 stoc/util/bootstrap.component                              |    5 +---
 udkapi/com/sun/star/reflection/TypeDescriptionProvider.idl |    4 +++
 ure/source/uretest/cppmain.cc                              |    1 
 4 files changed, 15 insertions(+), 10 deletions(-)

New commits:
commit 0af9970da3a23f63752033128976ad9ea420f828
Author: Stephan Bergmann <sbergman at redhat.com>
Date:   Thu Apr 25 17:43:03 2013 +0200

    Mark TypeDescriptionProvider service as "don't create by name"
    
    ...had to adapt one test that had picked this service apparently arbitrarily.
    
    Change-Id: Iaa17b7c622b9ac3601beb3ba931f7b1d99f649f1

diff --git a/stoc/util/bootstrap.component b/stoc/util/bootstrap.component
index 59761e0..a1f7859 100644
--- a/stoc/util/bootstrap.component
+++ b/stoc/util/bootstrap.component
@@ -35,9 +35,8 @@
     <service name="com.sun.star.lang.ServiceManager"/>
   </implementation>
   <implementation name="com.sun.star.comp.stoc.OServiceManagerWrapper"/>
-  <implementation name="com.sun.star.comp.stoc.RegistryTypeDescriptionProvider">
-    <service name="com.sun.star.reflection.TypeDescriptionProvider"/>
-  </implementation>
+  <implementation
+      name="com.sun.star.comp.stoc.RegistryTypeDescriptionProvider"/>
   <implementation name="com.sun.star.comp.stoc.SimpleRegistry">
     <service name="com.sun.star.registry.SimpleRegistry"/>
   </implementation>
diff --git a/udkapi/com/sun/star/reflection/TypeDescriptionProvider.idl b/udkapi/com/sun/star/reflection/TypeDescriptionProvider.idl
index af84f3c..d01581f 100644
--- a/udkapi/com/sun/star/reflection/TypeDescriptionProvider.idl
+++ b/udkapi/com/sun/star/reflection/TypeDescriptionProvider.idl
@@ -31,6 +31,10 @@
     service implementations read from source like the persistent registry
     database format.<br>
 
+    This old-style service definition mostly serves documentation purposes.  It
+    is not intended that an implementation of this service can be obtained at
+    the global service manager using this service identifier.
+
     @see com::sun::star::reflection::TypeDescriptionManager
     @see com::sun::star::reflection::XTypeDescription
 */
diff --git a/ure/source/uretest/cppmain.cc b/ure/source/uretest/cppmain.cc
index a302b23..331598e 100644
--- a/ure/source/uretest/cppmain.cc
+++ b/ure/source/uretest/cppmain.cc
@@ -112,7 +112,6 @@ private:
         "com.sun.star.reflection.CoreReflection",
         "com.sun.star.reflection.ProxyFactory",
         "com.sun.star.reflection.TypeDescriptionManager",
-        "com.sun.star.reflection.TypeDescriptionProvider",
         "com.sun.star.registry.ImplementationRegistration",
         "com.sun.star.registry.NestedRegistry",
         "com.sun.star.registry.SimpleRegistry",


More information about the Libreoffice-commits mailing list
diff --git a/qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java b/qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java
index d6a4483..ce389b1 100644
--- a/qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java
+++ b/qadevOOo/tests/java/ifc/script/_XEventAttacherManager.java
@@ -52,7 +52,7 @@ public class _XEventAttacherManager extends MultiMethodTest {
      */
     public XEventAttacherManager oObj = null;
 
-    int index;
+    private final int index = 0;
 
     /**
     * Test calls the method and stores index of new entry. <p>
@@ -60,7 +60,6 @@ public class _XEventAttacherManager extends MultiMethodTest {
     * and no exceptions were thrown. <p>
     */
     public void _insertEntry() {
-        index = 0;
         try {
             oObj.insertEntry(index);
             tRes.tested("insertEntry()", true);
@@ -260,7 +259,7 @@ public class _XEventAttacherManager extends MultiMethodTest {
     Object attachedObject;
 
     /**
     * Test creates instance of <code>TypeDescriptionProvider</code>,
     * stores it and attaches it to the entry with index stored in the method
     * <code>insertEntry()</code>. <p>
     * Has <b> OK </b> status if the method successfully returns
@@ -268,7 +267,6 @@ public class _XEventAttacherManager extends MultiMethodTest {
     * The following method tests are to be completed successfully before :
     * <ul>
     *  <li> <code> insertEntry() </code> : to have entry's index for attach</li>
-    * @see com.sun.star.reflection.TypeDescriptionProvider
     */
     public void _attach() {
         requiredMethod("insertEntry()");
@@ -276,13 +274,18 @@ public class _XEventAttacherManager extends MultiMethodTest {
         try {
             XMultiServiceFactory xMSF = (XMultiServiceFactory)tParam.getMSF();
             attachedObject = xMSF.createInstance
-                ( "com.sun.star.reflection.TypeDescriptionProvider" );
+                ( "com.sun.star.uno.NamingService" );
         } catch( com.sun.star.uno.Exception e ) {
-            log.println("Service not available" );
+            log.println("com.sun.star.uno.NamingService not available" );
             e.printStackTrace(log);
             tRes.tested("attach()", false);
             return;
         }
+        if (attachedObject == null) {
+            log.println("com.sun.star.uno.NamingService not available" );
+            tRes.tested("attach()", false);
+            return;
+        }
 
         try {
             oObj.attach(index, attachedObject, "param");
@@ -260,7 +259,7 @@ public class _XEventAttacherManager extends MultiMethodTest {
 
     /**
-    * Test creates instance of <code>TypeDescriptionProvider</code>,
+    * Test creates instance of <code>NamingService</code> (arbitrarily),
     * stores it and attaches it to the entry with index stored in the method
     * <code>insertEntry()</code>. <p>